windows: Rename create_map_window to windows_create_map

Change-Id: Ic491b97b0aa775201f6fc709fb0703b3fde4d9b2
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/windows.c b/windows.c
index 0111fea..1842108 100644
--- a/windows.c
+++ b/windows.c
@@ -537,7 +537,7 @@
 }
 
 /*
  * create_map_window() - Create a window mapping which maps the requested offset
  * @context:		The mbox context pointer
  * @this_window:	A pointer to update to the "new" window
  * @offset:		Absolute flash offset to create a mapping for (bytes)
@@ -551,7 +551,7 @@
  *
  * Return:	0 on success otherwise negative error code
  */
-int create_map_window(struct mbox_context *context,
+int windows_create_map(struct mbox_context *context,
 		      struct window_context **this_window, uint32_t offset,
 		      bool exact)
 {
@@ -537,7 +537,7 @@
 
 /*
- * create_map_window() - Create a window mapping which maps the requested offset
+ * windows_create_map() - Create a window mapping which maps the requested offset
  * @context:		The mbox context pointer
  * @this_window:	A pointer to update to the "new" window